==> vala-0.1.2.tar.bz2: vala-0.1.2/vala/valaconstructor.c <==
/* valaconstructor.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valaconstructor.h"
#include <vala/valablock.h>
#include <vala/valaformalparameter.h>
#include <vala/valasourcereference.h>
#include <vala/valacodevisitor.h>
#include <vala/valaconstructor.h>

struct _ValaConstructorPrivate {
	ValaBlock* _body;
	ValaFormalParameter* _this_parameter;
	gboolean _instance;
};
#define VALA_CONSTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CONSTRUCTOR, ValaConstructorPrivate))
enum  {
	VALA_CONSTRUCTOR_DUMMY_PROPERTY,
	VALA_CONSTRUCTOR_BODY,
	VALA_CONSTRUCTOR_THIS_PARAMETER,
	VALA_CONSTRUCTOR_INSTANCE
};
static void vala_constructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static void vala_constructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
static gpointer vala_constructor_parent_class = NULL;
static void vala_constructor_dispose (GObject * obj);


/**
 * Creates a new constructor.
 *
 * @param source reference to source code
 * @return       newly created constructor
 */
ValaConstructor* vala_constructor_new (ValaSourceReference* source)
{
	ValaConstructor * self;
	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
	self = g_object_newv (VALA_TYPE_CONSTRUCTOR, 0, NULL);
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
	return self;
}


static void vala_constructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaConstructor * self;
	self = ((ValaConstructor*) base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	vala_code_visitor_visit_constructor (visitor, self);
}


static void vala_constructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaConstructor * self;
	self = ((ValaConstructor*) base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	if (vala_constructor_get_body (self) != NULL) {
		vala_code_node_accept (VALA_CODE_NODE (vala_constructor_get_body (self)), visitor);
	}
}


ValaBlock* vala_constructor_get_body (ValaConstructor* self)
{
	g_return_val_if_fail (VALA_IS_CONSTRUCTOR (self), NULL);
	return self->priv->_body;
}


void vala_constructor_set_body (ValaConstructor* self, ValaBlock* value)
{
	ValaBlock* __temp2;
	ValaBlock* __temp1;
	g_return_if_fail (VALA_IS_CONSTRUCTOR (self));
	__temp2 = NULL;
	__temp1 = NULL;
	self->priv->_body = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp2);
}


ValaFormalParameter* vala_constructor_get_this_parameter (ValaConstructor* self)
{
	g_return_val_if_fail (VALA_IS_CONSTRUCTOR (self), NULL);
	return self->priv->_this_parameter;
}


void vala_constructor_set_this_parameter (ValaConstructor* self, ValaFormalParameter* value)
{
	ValaFormalParameter* __temp5;
	ValaFormalParameter* __temp4;
	g_return_if_fail (VALA_IS_CONSTRUCTOR (self));
	__temp5 = NULL;
	__temp4 = NULL;
	self->priv->_this_parameter = (__temp5 = (__temp4 = value, (__temp4 == NULL ? NULL : g_object_ref (__temp4))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), __temp5);
}


gboolean vala_constructor_get_instance (ValaConstructor* self)
{
	g_return_val_if_fail (VALA_IS_CONSTRUCTOR (self), FALSE);
	return self->priv->_instance;
}


void vala_constructor_set_instance (ValaConstructor* self, gboolean value)
{
	g_return_if_fail (VALA_IS_CONSTRUCTOR (self));
	self->priv->_instance = value;
}


static void vala_constructor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaConstructor * self;
	self = VALA_CONSTRUCTOR (object);
	switch (property_id) {
		case VALA_CONSTRUCTOR_BODY:
		g_value_set_object (value, vala_constructor_get_body (self));
		break;
		case VALA_CONSTRUCTOR_THIS_PARAMETER:
		g_value_set_object (value, vala_constructor_get_this_parameter (self));
		break;
		case VALA_CONSTRUCTOR_INSTANCE:
		g_value_set_boolean (value, vala_constructor_get_instance (self));
		break;
	}
}


static void vala_constructor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaConstructor * self;
	self = VALA_CONSTRUCTOR (object);
	switch (property_id) {
		case VALA_CONSTRUCTOR_BODY:
		vala_constructor_set_body (self, g_value_get_object (value));
		break;
		case VALA_CONSTRUCTOR_THIS_PARAMETER:
		vala_constructor_set_this_parameter (self, g_value_get_object (value));
		break;
		case VALA_CONSTRUCTOR_INSTANCE:
		vala_constructor_set_instance (self, g_value_get_boolean (value));
		break;
	}
}


static void vala_constructor_class_init (ValaConstructorClass * klass)
{
	vala_constructor_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaConstructorPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_constructor_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_constructor_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_constructor_dispose;
	VALA_CODE_NODE_CLASS (klass)->accept = vala_constructor_real_accept;
	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_constructor_real_accept_children;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_THIS_PARAMETER, g_param_spec_object ("this-parameter", "foo", "bar", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void vala_constructor_init (ValaConstructor * self)
{
	self->priv = VALA_CONSTRUCTOR_GET_PRIVATE (self);
	self->priv->_instance = TRUE;
}


static void vala_constructor_dispose (GObject * obj)
{
	ValaConstructor * self;
	ValaConstructorClass * klass;
	GObjectClass * parent_class;
	self = VALA_CONSTRUCTOR (obj);
	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
	klass = VALA_CONSTRUCTOR_CLASS (g_type_class_peek (VALA_TYPE_CONSTRUCTOR));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_constructor_get_type (void)
{
	static GType vala_constructor_type_id = 0;
	if (G_UNLIKELY (vala_constructor_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaConstructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_constructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaConstructor), 0, (GInstanceInitFunc) vala_constructor_init };
		vala_constructor_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaConstructor", &g_define_type_info, 0);
	}
	return vala_constructor_type_id;
}

==> vala-0.1.4.tar.bz2: vala-0.1.4/vala/valaconstructor.c <==
/* valaconstructor.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <vala/valaconstructor.h>
#include <vala/valablock.h>
#include <vala/valaformalparameter.h>
#include <vala/valasourcereference.h>
#include <vala/valacodevisitor.h>

struct _ValaConstructorPrivate {
	ValaBlock* _body;
	ValaFormalParameter* _this_parameter;
	gboolean _instance;
};
#define VALA_CONSTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CONSTRUCTOR, ValaConstructorPrivate))
enum  {
	VALA_CONSTRUCTOR_DUMMY_PROPERTY,
	VALA_CONSTRUCTOR_BODY,
	VALA_CONSTRUCTOR_THIS_PARAMETER,
	VALA_CONSTRUCTOR_INSTANCE
};
static void vala_constructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static void vala_constructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
static gpointer vala_constructor_parent_class = NULL;
static void vala_constructor_dispose (GObject * obj);


/**
 * Creates a new constructor.
 *
 * @param source reference to source code
 * @return       newly created constructor
 */
ValaConstructor* vala_constructor_new (ValaSourceReference* source) {
	ValaConstructor * self;
	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
	self = g_object_newv (VALA_TYPE_CONSTRUCTOR, 0, NULL);
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
	return self;
}


static void vala_constructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
	ValaConstructor * self;
	self = VALA_CONSTRUCTOR (base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	vala_code_visitor_visit_constructor (visitor, self);
}


static void vala_constructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
	ValaConstructor * self;
	self = VALA_CONSTRUCTOR (base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	if (vala_constructor_get_body (self) != NULL) {
		vala_code_node_accept (VALA_CODE_NODE (vala_constructor_get_body (self)), visitor);
	}
}


ValaBlock* vala_constructor_get_body (ValaConstructor* self) {
	g_return_val_if_fail (VALA_IS_CONSTRUCTOR (self), NULL);
	return self->priv->_body;
}


void vala_constructor_set_body (ValaConstructor* self, ValaBlock* value) {
	ValaBlock* _tmp2;
	ValaBlock* _tmp1;
	g_return_if_fail (VALA_IS_CONSTRUCTOR (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
}


ValaFormalParameter* vala_constructor_get_this_parameter (ValaConstructor* self) {
	g_return_val_if_fail (VALA_IS_CONSTRUCTOR (self), NULL);
	return self->priv->_this_parameter;
}


void vala_constructor_set_this_parameter (ValaConstructor* self, ValaFormalParameter* value) {
	ValaFormalParameter* _tmp2;
	ValaFormalParameter* _tmp1;
	g_return_if_fail (VALA_IS_CONSTRUCTOR (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), _tmp2);
}


gboolean vala_constructor_get_instance (ValaConstructor* self) {
	g_return_val_if_fail (VALA_IS_CONSTRUCTOR (self), FALSE);
	return self->priv->_instance;
}


void vala_constructor_set_instance (ValaConstructor* self, gboolean value) {
	g_return_if_fail (VALA_IS_CONSTRUCTOR (self));
	self->priv->_instance = value;
}


static void vala_constructor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValaConstructor * self;
	self = VALA_CONSTRUCTOR (object);
	switch (property_id) {
		case VALA_CONSTRUCTOR_BODY:
		g_value_set_object (value, vala_constructor_get_body (self));
		break;
		case VALA_CONSTRUCTOR_THIS_PARAMETER:
		g_value_set_object (value, vala_constructor_get_this_parameter (self));
		break;
		case VALA_CONSTRUCTOR_INSTANCE:
		g_value_set_boolean (value, vala_constructor_get_instance (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_constructor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValaConstructor * self;
	self = VALA_CONSTRUCTOR (object);
	switch (property_id) {
		case VALA_CONSTRUCTOR_BODY:
		vala_constructor_set_body (self, g_value_get_object (value));
		break;
		case VALA_CONSTRUCTOR_THIS_PARAMETER:
		vala_constructor_set_this_parameter (self, g_value_get_object (value));
		break;
		case VALA_CONSTRUCTOR_INSTANCE:
		vala_constructor_set_instance (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_constructor_class_init (ValaConstructorClass * klass) {
	vala_constructor_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaConstructorPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_constructor_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_constructor_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_constructor_dispose;
	VALA_CODE_NODE_CLASS (klass)->accept = vala_constructor_real_accept;
	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_constructor_real_accept_children;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void vala_constructor_init (ValaConstructor * self) {
	self->priv = VALA_CONSTRUCTOR_GET_PRIVATE (self);
	self->priv->_instance = TRUE;
}


static void vala_constructor_dispose (GObject * obj) {
	ValaConstructor * self;
	self = VALA_CONSTRUCTOR (obj);
	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
	G_OBJECT_CLASS (vala_constructor_parent_class)->dispose (obj);
}


GType vala_constructor_get_type (void) {
	static GType vala_constructor_type_id = 0;
	if (G_UNLIKELY (vala_constructor_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaConstructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_constructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaConstructor), 0, (GInstanceInitFunc) vala_constructor_init };
		vala_constructor_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaConstructor", &g_define_type_info, 0);
	}
	return vala_constructor_type_id;
}
